.. Hey Emacs, this is -*- rst -*-

   This file follows reStructuredText markup syntax; see
   http://docutils.sf.net/rst.html for more information.


.. _gc3libs:

-------------------------------
 Elasitcluster programming API
-------------------------------

.. toctree::

   elasticluster.rst
   elasticluster/cluster.rst
   elasticluster/conf.rst
   elasticluster/exceptions.rst
   elasticluster/gc3_config.rst
   elasticluster/helpers.rst
   elasticluster/main.rst
   elasticluster/module.rst
   elasticluster/providers.rst
   elasticluster/providers/ansible_provider.rst
   elasticluster/providers/ec2_boto.rst
   elasticluster/providers/gce.rst
   elasticluster/providers/openstack.rst
   elasticluster/repository.rst
   elasticluster/subcommands.rst
